@@ -13,4 +13,8 @@
 # limitations under the License.
 import os
 
+TEKTON_GROUP = 'tekton.dev'
+TEKTON_VERSION = os.environ.get('TEKTON_VERSION', 'v1beta1')
+TEKTON_API_VERSION = TEKTON_GROUP + '/' + TEKTON_VERSION
+
 TEKTON_LOGLEVEL = os.environ.get('TEKTON_LOGLEVEL', 'INFO').upper()
